@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package reconciler
 
@@ -16,7 +17,7 @@ import (
 
 	"github.com/golang/glog"
 	lru "github.com/golang/groupcache/lru"
-	tr "github.com/open-cluster-management/search-collector/pkg/transforms"
+	tr "github.com/stolostron/search-collector/pkg/transforms"
 )
 
 // Size of the LRU cache used to find out of order delete/add sequences
