@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
@@ -25,3 +26,17 @@ func TestTransformJob(t *testing.T) {
 	AssertEqual("completions", node.Properties["completions"], int64(1), t)
 	AssertEqual("parallelism", node.Properties["parallelism"], int64(1), t)
 }
+
+func TestJobBuildEdges(t *testing.T) {
+	// Build a fake NodeStore with nodes needed to generate edges.
+	nodes := make([]Node, 0)
+	nodeStore := BuildFakeNodeStore(nodes)
+
+	// Build edges from mock resource job.json
+	var j v1.Job
+	UnmarshalFile("job.json", &j, t)
+	edges := JobResourceBuilder(&j).BuildEdges(nodeStore)
+
+	// Validate results
+	AssertEqual("Job has no edges:", len(edges), 0, t)
+}
