@@ -4,8 +4,9 @@ OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
 The source code for this program is not published or otherwise divested of its trade secrets,
 irrespective of what has been deposited with the U.S. Copyright Office.
-Copyright (c) 2020 Red Hat, Inc.
+Copyright (c) 2020, 2021 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
@@ -27,17 +28,8 @@ func NodeResourceBuilder(n *v1.Node) *NodeResource {
 
 	var roles []string
 	labels := n.ObjectMeta.Labels
-	roleSet := map[string]struct{}{
-		"node-role.kubernetes.io/proxy":      {},
-		"node-role.kubernetes.io/management": {},
-		"node-role.kubernetes.io/master":     {},
-		"node-role.kubernetes.io/va":         {},
-		"node-role.kubernetes.io/etcd":       {},
-		"node-role.kubernetes.io/worker":     {},
-	}
-
 	for key, value := range labels {
-		if _, found := roleSet[key]; found && value == "" {
+		if strings.HasPrefix(key, "node-role.kubernetes.io/") && value == "" {
 			roles = append(roles, strings.TrimPrefix(key, "node-role.kubernetes.io/"))
 		}
 	}
@@ -54,6 +46,9 @@ func NodeResourceBuilder(n *v1.Node) *NodeResource {
 	node.Properties["architecture"] = n.Status.NodeInfo.Architecture
 	node.Properties["cpu"], _ = n.Status.Capacity.Cpu().AsInt64()
 	node.Properties["osImage"] = n.Status.NodeInfo.OSImage
+	// Workaround a bug in cAdvisor on ppc64le (see https://github.com/google/cadvisor/pull/2811)
+	// that causes a trailing null character in SystemUUID.
+	node.Properties["_systemUUID"] = strings.TrimRight(n.Status.NodeInfo.SystemUUID, "\000")
 	node.Properties["role"] = roles
 
 	return &NodeResource{node: node}
