@@ -26,7 +26,7 @@ func TestTransformNode(t *testing.T) {
 	AssertEqual("cpu", node.Properties["cpu"], int64(8), t)
 	AssertEqual("osImage", node.Properties["osImage"], "Ubuntu 16.04.5 LTS", t)
 	AssertEqual("_systemUUID", node.Properties["_systemUUID"], "4BCDE0D7-CFFB-4A8F-B6F8-0026F347AD93", t)
-	AssertDeepEqual("role", node.Properties["role"], []string{"etcd", "management", "master", "proxy", "va"}, t)
+	AssertDeepEqual("role", node.Properties["role"], []string{"etcd", "main", "management", "proxy", "va"}, t)
 }
 
 func TestNodeBuildEdges(t *testing.T) {
