@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
@@ -36,7 +37,8 @@ func ServiceResourceBuilder(s *v1.Service) *ServiceResource {
 	if len(s.Spec.Ports) > 0 {
 		for _, p := range s.Spec.Ports {
 			if p.NodePort != 0 {
-				ports = append(ports, strings.Join([]string{strconv.Itoa(int(p.Port)), ":", strconv.Itoa(int(p.NodePort)), "/", string(p.Protocol)}, ""))
+				ports = append(ports, strings.Join([]string{strconv.Itoa(int(p.Port)), ":",
+					strconv.Itoa(int(p.NodePort)), "/", string(p.Protocol)}, ""))
 			} else {
 				ports = append(ports, strings.Join([]string{strconv.Itoa(int(p.Port)), string(p.Protocol)}, "/"))
 			}
@@ -59,7 +61,7 @@ func (s ServiceResource) BuildEdges(ns NodeStore) []Edge {
 		return []Edge{}
 	}
 
-	// TODO future: Match a pod in another namespace , but config will be different in those cases.
+	// Future: Match a pod in another namespace , but config will be different in those cases.
 	pods := ns.ByKindNamespaceName["Pod"][s.node.Properties["namespace"].(string)]
 	nodeInfo := NodeInfo{
 		Name:      s.node.Properties["name"].(string),
